"""
Join Agent Package

An LLM-driven agent for intelligent data joining and relationship analysis.
"""

from join_agent.agent import JoinAgent

__version__ = "0.1.0"
__all__ = ["JoinAgent"]
